/*
 * Segment 2 (KEx),  SWE 2.DE Statischer Import MIF
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.mif.vew;

import java.util.Properties;

/**
 * Klasse mit allen f&uuml;r die Applikation notwendigen Parametern.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */
@SuppressWarnings("nls")
public final class MIFProperties extends Properties {
	/**
	 * serialVersionUID.
	 */
	private static final long serialVersionUID = 1L;

	/** Einziges Objekt dieser Klasse (Singleton). */
	private static MIFProperties _defaultProperties = new MIFProperties();

	// Properties aus Aufrufparametern
	public static final String PROP_KEY_WITH_GUI = "-guiStatischerImportMif";
	public static final String PROP_KEY_QUELLDATEI = "-mifDatenQuelle";
	public static final String PROP_KEY_PIDSPALTE = "-pidSpaltenName";
	public static final String PROP_KEY_QUELLTYPEN = "-quellObjektTypen";
	public static final String PROP_KEY_ZIELTYP = "-zielObjektTyp";
	public static final String PROP_KEY_KBPFAD = "-pfadNameKonfigurationsBereich";
	public static final String PROP_KEY_KV = "-KonfigurationsVerantwortlicher";
	public static final String PROP_KEY_KBPID = "-KonfigurationsBereichsPid";
	public static final String PROP_KEY_KBNAME = "-KonfigurationsBereichsName";
	public static final String PROP_KEY_KBINFO = "-KonfigurationsBereichsInfo";
	public static final String PROP_KEY_APPROXIMATION = "-abweichungApproximation";
	public static final String PROP_KEY_IMPORTALL = "-importAlleTypen";

	// zusätzliche Properties
	public static final String PROP_KEY_XMLDEBUG = "XMLmitDebugInfos";

	// Default-Werte
	public static final String DEFAULT_APPROXIMATION = "0.000010";

	/**
	 * Bestimmt das einziges Objekt dieser Klasse (Singleton).
	 *
	 * @return Einziges Objekt dieser Klasse (Singleton).
	 */
	public static MIFProperties getInstance() {
		return MIFProperties._defaultProperties;
	}

	/**
	 * Privater Konstruktor mit Standardwerten
	 */
	private MIFProperties() {
		setProperty(MIFProperties.PROP_KEY_XMLDEBUG, "nein"); // keine
																// Debuginformationen
																// in
		// der XML-Datei
		setProperty(MIFProperties.PROP_KEY_APPROXIMATION, MIFProperties.DEFAULT_APPROXIMATION);
		setProperty(MIFProperties.PROP_KEY_WITH_GUI, "nein");
		setProperty(MIFProperties.PROP_KEY_IMPORTALL, "ja");
	}

	/**
	 * Hilfsmethode zum Bestimmen, ob ein bin&auml;rer Parameter (ja/nein) auf
	 * 'ja' gesetzt ist.
	 *
	 * @param key
	 *            Property-Schl&uuml;ssel.
	 *
	 * @return true, wenn der Wert der Property zum Schl&uuml;ssel 'Ja' ist,
	 *         ansonsten false.
	 */
	public boolean istAktiv(final String key) {
		return MIFProperties._defaultProperties.getProperty(key).equalsIgnoreCase("Ja");
	}
}
